==> curlpp-0.5.2.tbz: include/curlpp/SList.hpp <==
/*
 *    Copyright (c) <2002-2003> <Jean-Philippe Barrette-LaPierre>
 *    
 *    Permission is hereby granted, free of charge, to any person obtaining
 *    a copy of this software and associated documentation files 
 *    (curlpp), to deal in the Software without restriction, 
 *    including without limitation the rights to use, copy, modify, merge,
 *    publish, distribute, sublicense, and/or sell copies of the Software,
 *    and to permit persons to whom the Software is furnished to do so, 
 *    subject to the following conditions:
 *    
 *    The above copyright notice and this permission notice shall be included
 *    in all copies or substantial portions of the Software.
 *    
 *    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 *    OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
 *    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
 *    CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
 *    TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 *    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef SLIST_HPP
#define SLIST_HPP

#include <list>

#include "dllfct.h"
#include "cURL.hpp"

namespace cURLpp
{
  /**
   * This class is binding the curl_slist struct.
   */
  class CURLPPAPI SList
  {
  public:
    SList();
    SList(const SList &rhs);
    SList(const std::list< std::string > &list);
    ~SList();

    SList &operator=(const std::list< std::string > &list);
    operator std::list< std::string > ();

    cURL::curl_slist *cslist() const;
    std::list< std::string > list();

  private:
    void set(const std::list< std::string > &list);
    void update();
     
    cURL::curl_slist *mList;
    std::list< std::string > mData;
  };
}


std::ostream CURLPPAPI &operator<<(std::ostream &stream, const std::list< std::string > &value);


#endif

==> curlpp-0.6.1.tbz: include/curlpp/SList.hpp <==
/*
 *    Copyright (c) <2002-2003> <Jean-Philippe Barrette-LaPierre>
 *    
 *    Permission is hereby granted, free of charge, to any person obtaining
 *    a copy of this software and associated documentation files 
 *    (curlpp), to deal in the Software without restriction, 
 *    including without limitation the rights to use, copy, modify, merge,
 *    publish, distribute, sublicense, and/or sell copies of the Software,
 *    and to permit persons to whom the Software is furnished to do so, 
 *    subject to the following conditions:
 *    
 *    The above copyright notice and this permission notice shall be included
 *    in all copies or substantial portions of the Software.
 *    
 *    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 *    OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
 *    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
 *    CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
 *    TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 *    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef SLIST_HPP
#define SLIST_HPP

#include <curl/curl.h>
#include <list>

#include "dllfct.h"


namespace cURLpp
{
  /**
   * This class is binding the curl_slist struct.
   */
  class CURLPPAPI SList
  {
  public:
    SList();
    SList(const SList &rhs);

    /**
     * the list passed in argument is now possessed by
     * the class.
     */
    SList(curl_slist *list);

    SList(const std::list< std::string > &list);
    ~SList();

    SList &operator=(const std::list< std::string > &list);
    operator std::list< std::string > ();

    curl_slist *cslist() const;
    std::list< std::string > list();

  private:
    void set(const std::list< std::string > &list);
    void update();
    void clear();
    void constructFrom(curl_slist *list);

     
    curl_slist *mList;
    std::list< std::string > mData;
  };
}


std::ostream CURLPPAPI &operator<<(std::ostream &stream, const std::list< std::string > &value);


#endif
